# SB9500 Python Kütüphanesi #

Bu kütüphane, SB-9500 insansı robotunun işlediği Yapay Zeka sisteminde kullanılan özel kütüphaneleri içerir.

> Sesli konuşma kaynağına erişmek için projenize "import sb9500" dahil edin.
>> Daha sonrasında her defada api anahtarı belirtmemek için projenizin en üst satırlarından birine şu kodu ekleyin: ( sb9500.tts_ApiKey = "xxxxx" ) (xxxxx yerine ElevenLabs üzerinden aldığınız API anahtarını girin.)
>>> Kod: sb9500.speak(text="Merhaba Dünya!")

> Örnek kodu incelemek için aşağıdaki adrese gidin.
https://salihbastanmedia.github.io/SB-9500-WEB/ec_speak.html

Özelleştirmeler
>> text="Buraya yazdığınız herşey sesli okutulur"
>> file_name="buraya ses dosyasının adı yazılır (isteğe bağlı)"
>> audio_type=".mp3"
>> model_id="eleven_multilingual_v2"
>> stability=0.5
>> similarity_boost=0.5

## İletişim
salihbastanmaill@gmail.com
sb9500mail@gmail.com
www.bashtan.store
Instagram: @salihbastan